@@ -1,10 +1,9 @@
 from os import path
 from sys import stderr
+from sys import _getframe
 from inspect import signature
 from inspect import getsource
 from inspect import isfunction
-from inspect import getmembers
-from inspect import currentframe
 from typing import Callable, Any, Iterable, Tuple
 
 from .exceptions import *
@@ -290,12 +289,12 @@ def __check_is_function_for_provider(func: Callable[[Any], None]):
                                        f"has more than 1 argument!")
 
 
-def DATA_FILE(provider_name: str, file_path: str, encoding: str = 'UTF-8', map_function: Callable = None):
+def DATA_FILE(file_path: str, provider_name: str = None, encoding: str = 'UTF-8', map_function: Callable = None):
     """
     Function to use text file as data provider for test. Reads file lazily, do not get it to memory.
     The function name explicitly stays uppercase for user to pay attention to it.
     User must call it at the global module namespace, but not at fixtures or in tests!
-    :param provider_name: name of the data-provider for use it in test
+    :param provider_name: name of the data-provider for use it in test, if not specified the file_path be used as name
     :param file_path: file name or path-to-file with name, it can be full or relative path, but it must be "visible"
     (accessible from module, where it is declared)
     :param encoding: encoding of the text file (default UTF-8)
@@ -307,11 +306,16 @@ def DATA_FILE(provider_name: str, file_path: str, encoding: str = 'UTF-8', map_f
     def wrapper():
         return DataFile(real_path, encoding=encoding, map_function=map_function)
 
-    frame_ = [fr for fr in getmembers(currentframe()) if fr[0] == 'f_back']
-    assert frame_  # It can't be no last frame!
-    frame = frame_[0]
-    first_path = path.split(frame[1].f_globals['__file__'])[0]
-    real_path = path.join(first_path, file_path)
-    if not is_file_exists(real_path):
-        raise ValueError(f'Cant find file! Is file "{real_path}" exists?')
-    data(name=provider_name)(wrapper)
+    if provider_name is None:
+        provider_name = file_path
+    try:
+        # Get last frame to verify file-path
+        frame = _getframe(1)
+        assert frame  # It can't be no last frame!
+        first_path = path.split(frame.f_globals['__file__'])[0]
+        real_path = path.join(first_path, file_path)
+        if not is_file_exists(real_path):
+            raise ValueError(f'Cant find file! Is file "{real_path}" exists?')
+        data(name=provider_name)(wrapper)
+    finally:
+        del frame
